@@ -30,14 +30,14 @@ use {
 
 // Data placement should be aligned at the next boundary. Without alignment accessing the memory may
 // crash on some architectures.
-const ALIGN_BOUNDARY_OFFSET: usize = mem::size_of::<u64>();
+pub const ALIGN_BOUNDARY_OFFSET: usize = mem::size_of::<u64>();
 macro_rules! u64_align {
     ($addr: expr) => {
         ($addr + (ALIGN_BOUNDARY_OFFSET - 1)) & !(ALIGN_BOUNDARY_OFFSET - 1)
     };
 }
 
-const MAXIMUM_APPEND_VEC_FILE_SIZE: u64 = 16 * 1024 * 1024 * 1024; // 16 GiB
+pub const MAXIMUM_APPEND_VEC_FILE_SIZE: u64 = 16 * 1024 * 1024 * 1024; // 16 GiB
 
 pub type StoredMetaWriteVersion = u64;
 
@@ -286,11 +286,11 @@ impl AppendVec {
         // This mutex forces append to be single threaded, but concurrent with reads
         // See UNSAFE usage in `append_ptr`
         let _lock = self.append_lock.lock().unwrap();
-        self.current_len.store(0, Ordering::Relaxed);
+        self.current_len.store(0, Ordering::Release);
     }
 
     pub fn len(&self) -> usize {
-        self.current_len.load(Ordering::Relaxed)
+        self.current_len.load(Ordering::Acquire)
     }
 
     pub fn is_empty(&self) -> bool {
@@ -301,7 +301,7 @@ impl AppendVec {
         self.file_size
     }
 
-    pub fn file_name(slot: Slot, id: usize) -> String {
+    pub fn file_name(slot: Slot, id: impl std::fmt::Display) -> String {
         format!("{}.{}", slot, id)
     }
 
@@ -360,7 +360,7 @@ impl AppendVec {
             offset = next_offset;
             num_accounts += 1;
         }
-        let aligned_current_len = u64_align!(self.current_len.load(Ordering::Relaxed));
+        let aligned_current_len = u64_align!(self.current_len.load(Ordering::Acquire));
 
         (offset == aligned_current_len, num_accounts)
     }
@@ -419,7 +419,7 @@ impl AppendVec {
         for val in vals {
             self.append_ptr(offset, val.0, val.1)
         }
-        self.current_len.store(*offset, Ordering::Relaxed);
+        self.current_len.store(*offset, Ordering::Release);
         Some(pos)
     }
 
