@@ -1,6 +1,6 @@
 // Partial SPL Associated Token Account declarations inlined to avoid an external dependency on the spl-associated-token-account crate
 solana_sdk::declare_id!("ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL");
 
-pub(crate) mod program_v1_0_4 {
-    solana_sdk::declare_id!("nata4apBRD9S9256v3X8RxDQ7jmK7wLEsGNHhRNWFq3");
+pub(crate) mod program_v1_1_0 {
+    solana_sdk::declare_id!("NatA1Zyo48dJ7yuwR7cGURwhskKA8ywUyxb9GvG7mTC");
 }
